@@ -47,6 +47,7 @@ class Archive:public File
     bool DummyCmd;
     CommandData *Cmd;
 
+    int RecoveryPercent;
 
     RarTime LatestTime;
     int LastReadBlock;
@@ -58,13 +59,14 @@ class Archive:public File
     bool ProhibitQOpen;
 #endif
   public:
-    Archive(CommandData *InitCmd=NULL);
+    Archive(CommandData *InitCmd=nullptr);
     ~Archive();
     static RARFORMAT IsSignature(const byte *D,size_t Size);
     bool IsArchive(bool EnableBroken);
     size_t SearchBlock(HEADER_TYPE HeaderType);
     size_t SearchSubBlock(const wchar *Type);
     size_t SearchRR();
+    int GetRecoveryPercent() {return RecoveryPercent;}
     size_t ReadHeader();
     void CheckArc(bool EnableBroken);
     void CheckOpen(const std::wstring &Name);
@@ -147,6 +149,9 @@ class Archive:public File
     bool NewArchive;
 
     std::wstring FirstVolumeName;
+#ifdef PROPAGATE_MOTW
+    MarkOfTheWeb Motw;
+#endif
 };
 
 
