@@ -2,7 +2,6 @@
  *  Contents: 'Carryless rangecoder' by Dmitry Subbotin                     *
  ****************************************************************************/
 
-const uint TOP=1 << 24, BOT=1 << 15;
 
 class RangeCoder
 {
@@ -12,7 +11,7 @@ class RangeCoder
     inline uint GetCurrentShiftCount(uint SHIFT);
     inline void Decode();
     inline void PutChar(unsigned int c);
-    inline unsigned int GetChar();
+    inline byte GetChar();
 
     uint low, code, range;
     struct SUBRANGE 
